@@ -3,7 +3,6 @@
 import json
 import platform
 import multiprocessing
-from io import StringIO
 
 
 def invoke_semgrep(paths, scan_rules, **kwargs):
@@ -17,23 +16,31 @@ def invoke_semgrep(paths, scan_rules, **kwargs):
         cpu_count = multiprocessing.cpu_count()
     except NotImplementedError:
         cpu_count = 1  # CPU count is not implemented on Windows
-    util.set_flags(False, True, False)  # Verbose, Quiet, Force_color
-    io_capture = StringIO()
-    output_handler = OutputHandler(
-        OutputSettings(
-            output_format=OutputFormat.JSON,
-            output_destination=None,
-            error_on_findings=False,
-            verbose_errors=False,
-            strict=False,
-            timeout_threshold=3,
-            json_stats=False,
-            json_time=False,
-            output_per_finding_max_lines_limit=None,
-        ),
-        stdout=io_capture,
+    # Semgrep output formatting
+    util.set_flags(
+        verbose=False,
+        debug=False,
+        quiet=True,
+        force_color=False)
+    output_settings = OutputSettings(
+        output_format=OutputFormat.JSON,
+        output_destination=None,
+        error_on_findings=False,
+        verbose_errors=False,
+        strict=False,
+        timeout_threshold=3,
+        json_stats=False,
+        output_per_finding_max_lines_limit=None,
     )
-    semgrep_main.main(
+    output_handler = OutputHandler(output_settings)
+    (
+        filtered_matches_by_rule,
+        _all_targets,
+        _filtered_rules,
+        _profiler,
+        _profiling_data,
+        _shown_severities,
+    ) = semgrep_main.main(
         output_handler=output_handler,
         target=[pt.as_posix() for pt in paths],
         jobs=cpu_count,
@@ -44,5 +51,7 @@ def invoke_semgrep(paths, scan_rules, **kwargs):
         timeout_threshold=3,
         **kwargs,
     )
-    output_handler.close()
-    return json.loads(io_capture.getvalue())
+    output_handler.rule_matches = [
+        m for ms in filtered_matches_by_rule.values() for m in ms
+    ]
+    return json.loads(output_handler._build_output())
